from django.db import models

from conf import DRIVE_UPLOAD_URL, DRIVE_STATIC_URL
import form_fields

class S4DriveFileField(models.Field):
    def get_internal_type(self):
        return "TextField"

    def __init__(self, url=DRIVE_UPLOAD_URL, drive_static_url=DRIVE_STATIC_URL, *args, **kwargs):
        self.url = url
        self.drive_static_url = drive_static_url
        return super(S4DriveFileField, self).__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        defaults = {
            'form_class': form_fields.S4DriveFileField,
            "url": self.url,
            "drive_static_url": self.drive_static_url,
        }
        defaults.update(kwargs)
        return super(S4DriveFileField, self).formfield(**defaults)

    def south_field_triple(self):
        from south.modelsinspector import introspector
        field_class = "django.db.models.TextField"
        args, kwargs = introspector(self)
        return (field_class, args, kwargs)



from django.forms.widgets import Widget
from django.template import loader
from django.utils.safestring import mark_safe
from django.conf import settings


class S4DriveFileWidget(Widget):
    def __init__(self, url, drive_static_url, **kwargs):
        self.url = url
        self.drive_static_url = drive_static_url
        return super(S4DriveFileWidget, self).__init__(**kwargs)

    def render(self, name, value, attrs=None):
        if not value: value = ""
        return mark_safe(loader.render_to_string("django_s4/s4_drive_file.html", {
            "STATIC_URL": settings.STATIC_URL,
            "DRIVE_STATIC_URL": self.drive_static_url,
            "name": name,
            "url": self.url,
            "value": value,
        }))


#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(
    name = "django-s4",
    version = "1.2.0",
    url = 'https://github.com/sikaondrej/django-s4/',
    license = 'GNU LGPL v.3',
    description = "",
    author = 'Ondrej Sika',
    author_email = 'ondrej@ondrejsika.com',
    packages = find_packages(),
    requires = [],
    include_package_data = True,
    zip_safe = False,
)



from django import forms
from django.db.models import get_model

import widgets

class S4DriveFileField(forms.CharField):
    def __init__(self, url, drive_static_url, **kwargs):
        defaults = {
            'widget': widgets.S4DriveFileWidget(url, drive_static_url),
        }
        defaults.update(kwargs)
        super(S4DriveFileField, self).__init__(**defaults)